==> tweego_0.2.1-1.tar.gz: tweego-0.2.1/src/applicationItems/dialog.h <==
/*
 *
 *  Copyright (c) 2010 Zagaia (INdT - Instituto Nokia de Tecnologia/
 *       FUCAPI - Fundação Centro de Análise, Pesquisa e Inovação Tecnológica)
 *
 *  This file is part of TweeGo.
 *
 *  TweeGo is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  TweeGo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with TweeGo. If not, see <http://www.gnu.org/licenses/>
 *
 */

#ifndef DIALOG_H
#define DIALOG_H

#include <QtGui/QGraphicsLayout>
#include <QtGui/QGraphicsWidget>
#include <QtGui/QMessageBox>
#include <QtGui/QPainter>
#include <QtGui/QStyleOptionGraphicsItem>
#include <QtGui/QWidget>

#include <QtCore/QAbstractAnimation>
#include <QtCore/QObject>
#include <QtCore/QEventLoop>
#include <QtCore/QPropertyAnimation>
#include <QtCore/QRectF>
#include <QtCore/QString>
#include <QtCore/QVariantAnimation>

#include "twitterapplicationitem.h"
#include "twitterbutton.h"

/*!
 * \class DialogView
 *
 * \brief Dialog View class
 *
 * Handles dialog view windows.
 */
class DialogView : public TwitterApplicationItem
{
    Q_OBJECT

public:
    enum Type { Warning, Error };

    DialogView(DialogView::Type type, QGraphicsWidget *parent = 0);
    ~DialogView();
    void exec();
    void setTitle(const QString &title);
    void setMessage(const QString &message);
    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);

signals:
    void yesPressed(void);
    void noPressed(void);

public slots:
    int exit(void);
    void buttonPressed();

private:
    Type _type;
    QString _title;
    QString _message;
    QEventLoop _eventLoop;
    TwitterButton *_okButton;
    TwitterButton *_yesButton;
    TwitterButton *_noButton;
};

#endif

==> tweego_0.3.0.tar.gz: tweego-0.3.0/src/applicationItems/dialog.h <==
/*
 *
 *  Copyright (c) 2010 Zagaia (INdT - Instituto Nokia de Tecnologia/
 *       FUCAPI - Fundação Centro de Análise, Pesquisa e Inovação Tecnológica)
 *
 *  This file is part of TweeGo.
 *
 *  TweeGo is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  TweeGo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with TweeGo. If not, see <http://www.gnu.org/licenses/>
 *
 */

#ifndef DIALOG_H
#define DIALOG_H

#include <QtGui/QGraphicsLayout>
#include <QtGui/QGraphicsWidget>
#include <QtGui/QMessageBox>
#include <QtGui/QPainter>
#include <QtGui/QStyleOptionGraphicsItem>
#include <QtGui/QWidget>

#include <QtCore/QAbstractAnimation>
#include <QtCore/QObject>
#include <QtCore/QEventLoop>
#include <QtCore/QPropertyAnimation>
#include <QtCore/QRectF>
#include <QtCore/QString>
#include <QtCore/QVariantAnimation>

#include "twitterapplicationitem.h"
#include "twitterbutton.h"

/*!
 * \class DialogView
 *
 * \brief Dialog View class
 *
 * Handles dialog view windows.
 */
class DialogView : public TwitterApplicationItem
{
    Q_OBJECT

public:
    enum Type { Warning, Error, Location };

    DialogView(DialogView::Type type, QString message="", QGraphicsWidget *parent = 0);
    void setMessage(const QString &message);

private:
    void createConnects(void);

signals:
    void yesPressed(void);
    void noPressed(void);
    void getIP(void);
    void getGPS(void);
    void cancelPressed(void);

protected:
    void mousePressEvent(QGraphicsSceneMouseEvent *event);

public slots:
    void buttonPressed();

private:
    Type _type;
    QString _message;
    TwitterButton *_yesButton;
    TwitterButton *_noButton;
    TwitterButton *_ipButton;
    TwitterButton *_gpsButton;
    TwitterButton *_cancelButton;
    QGraphicsRectItem *m_background;
};

#endif
